@@ -2,21 +2,20 @@
  * Copyright (C) 1999, 2002, 2003  Free Software Foundation, Inc.
  * 
  * This file is part of GNU libmatheval
- *
- * GNU libmatheval is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
+ * 
+ * GNU libmatheval is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2, or (at your option) any later
+ * version.
+ * 
  * GNU libmatheval is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with program; see the file COPYING. If not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
- * USA.
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ * for more details.
+ * 
+ * You should have received a copy of the GNU General Public License along with
+ * program; see the file COPYING. If not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef NODE_H
@@ -41,15 +40,13 @@ typedef struct _Node {
 			Record         *record;	/* Symbol table record for
 						 * function.  */
 			struct _Node   *child;	/* Function argument node.  */
-		}
-		                function;	/* Structure representing
+		}               function;	/* Structure representing
 						 * function.  */
 		struct {
 			char            operator;	/* Operator type ('-'
 							 * for unary minus).  */
 			struct _Node   *child;	/* Operand node.  */
-		}
-		                un_op;	/* Structure representing unary
+		}               un_op;	/* Structure representing unary
 					 * operator.  */
 		struct {
 			char            operator;	/* Operator type ('+'
@@ -59,13 +56,10 @@ typedef struct _Node {
 							 * for division and '^'
 							 * for exponentiation).  */
 			struct _Node   *left, *right;	/* Operands nodes.  */
-		}
-		                bin_op;	/* Structure representing binary
+		}               bin_op;	/* Structure representing binary
 					 * operator.  */
-	}
-	                data;
-}
-                Node;
+	}               data;
+}               Node;
 
 /*
  * Create node of given type and initialize it from optional arguments.
